autowisp.database.data_model.hdf5_structure_versions module — AutoWISP documentation

# autowisp.database.data_model.hdf5_structure_versions module

## Class Inheritance Diagram

Define the hdf5_structure_versions table.

class autowisp.database.data_model.hdf5_structure_versions.HDF5StructureVersion(**kwargs)

  Bases: `DataModelBase`

  The versions of structures for the HDF5 pipeline products.

  attributes
  datasets
  hdf5_product_id

    The type of pipeline product this structure configuration version is for.

  id

    A unique identifier for each row.

  links
  product
  timestamp

    When record was last changed

  version

    An identifier for distinguishing the separate configuration versions of a single pipeline product type.